"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.biometricAuthentication = void 0;
var _errors = require("./errors");
var _reactNativeBiometrics = _interopRequireDefault(require("react-native-biometrics"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const rnBiometrics = new _reactNativeBiometrics.default({
  allowDeviceCredentials: true
});

/**
 * Requests user biometrics authentication. Throws an error if not authenticated.
 */
const biometricAuthentication = async () => {
  await rnBiometrics.isSensorAvailable().then(async biometrics => {
    if (biometrics.available) {
      const biometricCheck = await rnBiometrics.simplePrompt({
        promptMessage: 'Awaiting Authorization'
      });
      if (biometricCheck.error) {
        // Caller should catch and handle as 'unauthorized'.
        throw new _errors.BiometricsError(biometricCheck.error);
      }
      if (!biometricCheck.success) {
        // User is not authorized.
        throw new _errors.BiometricsError('User not authorized');
      }
    } else {
      // No biometrics available, passive authorization.
    }
  })
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  .catch(() => {
    throw new _errors.BiometricsError('User not authorized');
  });
};
exports.biometricAuthentication = biometricAuthentication;
//# sourceMappingURL=biometrics.js.map