import * as Sentry from '@sentry/react-native';
import { getBuildNumber, getVersion } from 'react-native-device-info';
import { AJPElements } from '..';
var SentrySeverityMap = /*#__PURE__*/function (SentrySeverityMap) {
  SentrySeverityMap[SentrySeverityMap["debug"] = 0] = "debug";
  SentrySeverityMap[SentrySeverityMap["info"] = 1] = "info";
  SentrySeverityMap[SentrySeverityMap["warning"] = 2] = "warning";
  SentrySeverityMap[SentrySeverityMap["error"] = 3] = "error";
  SentrySeverityMap[SentrySeverityMap["fatal"] = 4] = "fatal";
  return SentrySeverityMap;
}(SentrySeverityMap || {});
const init = userId => {
  if (!__DEV__ && Sentry.init) {
    Sentry.init({
      dsn: AJPElements.get('sentryEndpoint'),
      environment: AJPElements.get('buildEnvironment'),
      debug: false,
      enableAutoSessionTracking: true,
      release: getVersion(),
      dist: getBuildNumber()
    });
    userId && Sentry.setUser({
      id: userId
    });
  }
};
const sentryTransport = props => {
  var _props$level, _props$level2;
  if (props.level.text.includes('session')) {
    return;
  }
  const severity = (props === null || props === void 0 || (_props$level = props.level) === null || _props$level === void 0 ? void 0 : _props$level.severity) === undefined ? SentrySeverityMap.error : props === null || props === void 0 || (_props$level2 = props.level) === null || _props$level2 === void 0 ? void 0 : _props$level2.severity;
  const sentrySeverity = SentrySeverityMap[severity];
  if (__DEV__) {
    let consoleLogger = console.log;
    switch (SentrySeverityMap[severity]) {
      case 'warning':
        consoleLogger = console.warn;
        break;
      case 'error':
        consoleLogger = console.error;
        break;
      default:
        break;
    }
    consoleLogger(props === null || props === void 0 ? void 0 : props.msg);
  } else {
    // console.log(`SENTRY: [${sentrySeverity}] ${props?.msg}`);
    if (AJPElements.get('sentryLoggingEnabled') === true && severity > SentrySeverityMap.info) {
      Sentry.withScope(scope => {
        scope.setLevel(sentrySeverity);
        Sentry.captureMessage(props === null || props === void 0 ? void 0 : props.msg);
      });
    }
  }
  return true;
};
export { init, sentryTransport };
//# sourceMappingURL=sentryLog.js.map